# eric7.MicroPython.EthernetDialogs

Package implementing Ethernet related dialogs.

### Modules

EthernetController | Module implementing the Ethernet related functionality.
EthernetStatusDialog | Module implementing a dialog to show Ethernet related status information.
IPv4AddressDialog | Module implementing a dialog to enter an IPv4 address.
WiznetUtilities | Module implementing WIZnet 5x00 related utility functions.